%ADICIÓN DE HANGOVER.
%function [vad,burstcount,hangcount]=vadhang(vvad,burstcount,hangcount)
%Entradas:
%vvad:decisión del vad.
%burstcount:contador de tramas.
%hangcount:contador de hangover.
%Salidas:
%vad:decisión del vad con hangover.
%burstcount:contador de tramas.
%hangcount:contador de hangover.
function [vad,burstcount,hangcount]=vadhang(vvad,burstcount,hangcount)
burstconst=3;
hangconst=5;
if (vvad==1)
   burstcount=burstcount+1;
else
   burstcount=0;
end
if(burstcount>=burstconst)
   hangcount=hangconst;
   burstcount=burstconst;
end
if(hangcount>=0);
   vad=1;
else
   vad=vvad;
end
if(hangcount>=0)
   hangcount=hangcount-1;
end
